@@ -2,15 +2,18 @@ import os
 from dataclasses import dataclass, asdict
 from typing import Optional
 
-from .log import FAIL, LOG
+from daml_dit_api import \
+    DABL_META_NAME
 
+from .log import FAIL, LOG
 
 @dataclass(frozen=True)
 class Configuration:
     health_port: int
     ledger_url: str
     ledger_id: str
-    integration_metadata_path: str
+    dit_meta_path: str
+    integration_spec_path: str
     type_id: 'Optional[str]'
     run_as_party: 'Optional[str]'
     log_level: int
@@ -52,7 +55,8 @@ def get_default_config() -> 'Configuration':
         health_port=envint('DABL_HEALTH_PORT', 8089),
         ledger_url=env('DABL_LEDGER_URL', 'http://localhost:6865'),
         ledger_id=env('DABL_LEDGER_ID', 'cloudbox'),
-        integration_metadata_path=env('DABL_INTEGRATION_METADATA_PATH', 'int_args.yaml'),
+        dit_meta_path=env('DAML_DIT_META_PATH', DABL_META_NAME),
+        integration_spec_path=env('DABL_INTEGRATION_METADATA_PATH', 'int_args.yaml'),
         type_id=optenv('DABL_INTEGRATION_TYPE_ID'),
         run_as_party=optenv('DAML_LEDGER_PARTY'),
         log_level=envint('DABL_LOG_LEVEL', 0),
